/* ###
 * IP: GHIDRA
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ghidra.framework.store;

import ghidra.util.exception.UsrException;

/**
 * Indicates a failure to obtain a required lock.
 */
public class LockException extends UsrException {
	
    /**
     * Construct a new LockException with the given message
     * @param msg    the exception message
     */
    public LockException(String msg) {
        super(msg);
    }
    
}
